## $Id: interfaces.py 13035 2015-06-05 08:25:11Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.aaue')

# It's recommended to replicate all fields from the base package here.
class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    #school_fee_base = schema.Float(
    #    title = _(u'School Fee Instalments'),
    #    default = 0.0,
    #    required = True,
    #    )

    #school_fee = schema.Float(
    #    title = _(u'School Fee (not FP)'),
    #    default = 0.0,
    #    required = True,
    #    )

    school_fee_1 = schema.Float(
        title = _(u'Regular Initial School Fee'),
        default = 0.0,
        required = True,
        )

    school_fee_2 = schema.Float(
        title = _(u'Returning School Fee'),
        default = 0.0,
        required = True,
        )

    school_fee_3 = schema.Float(
        title = _(u'FP Initial School Fee'),
        default = 0.0,
        required = True,
        )

    application_fee = schema.Float(
        title = _(u'Application Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee = schema.Float(
        title = _(u'Regular Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    clearance_fee_fp = schema.Float(
        title = _(u'FP Acceptance Fee'),
        default = 0.0,
        required = True,
        )

    booking_fee = schema.Float(
        title = _(u'Booking Fee'),
        default = 0.0,
        required = True,
        )

    transcript_fee = schema.Float(
        title = _(u'Transcript Fee'),
        default = 0.0,
        required = True,
        )

    # Additional fees in custom package

    maint_fee = schema.Float(
        title = _(u'Maintenance Fee'),
        default = 0.0,
        required = True,
        )

    gown_fee = schema.Float(
        title = _(u'Gown Fee'),
        default = 0.0,
        required = True,
        )

    transfer_fee = schema.Float(
        title = _(u'Transfer Fee'),
        default = 0.0,
        required = True,
        )

    penalty_ug = schema.Float(
        title = _(u'UG Penalty Fee'),
        default = 0.0,
        required = True,
        )

    penalty_pg = schema.Float(
        title = _(u'PG Penalty Fee'),
        default = 0.0,
        required = True,
        )

    late_registration_fee = schema.Float(
        title = _(u'Late Course Reg. Fee'),
        default = 0.0,
        required = True,
        )

    coursereg_deadline = schema.Datetime(
        title = _(u'Course Reg. Deadline'),
        required = False,
        description = _('Example: ') + u'2011-12-31 23:59:59+01:00',
        )


    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order